@@ -1,7 +1,7 @@
 # pylint: disable=missing-docstring
 import torch
 import torch.nn as nn
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 from raylab.utils.pytorch import initialize_
 
