@@ -1,7 +1,7 @@
 # pylint:disable=missing-module-docstring
 import torch
 import torch.nn as nn
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 
 class StdNormalParams(nn.Module):
