@@ -1,6 +1,6 @@
 """Support for modules with action value functions as critics."""
 import torch.nn as nn
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 from raylab.utils.dictionaries import deep_merge
 
