@@ -1,7 +1,7 @@
 """SVG model architecture."""
 import torch
 import torch.nn as nn
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 
 from raylab.utils.dictionaries import deep_merge
 
