@@ -9,7 +9,7 @@ from ray.rllib.models.model import flatten
 from ray.rllib.models.model import restore_original_dimensions
 from ray.rllib.policy.policy import LEARNER_STATS_KEY
 from ray.rllib.policy.policy import Policy
-from ray.rllib.utils.annotations import override
+from ray.rllib.utils import override
 from ray.rllib.utils.torch_ops import convert_to_non_torch_type
 from ray.rllib.utils.tracking_dict import UsageTrackingDict
 from ray.tune.logger import pretty_print
